"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.output = void 0;
const tslib_1 = require("tslib");
const reporter_1 = require("./reporter");
const strip_ansi_1 = tslib_1.__importDefault(require("strip-ansi"));
async function output(params) {
    let out;
    switch (params.format.toLowerCase()) {
        case 'json': {
            process.stdout.write(JSON.stringify(params.results, null, 2));
            return;
        }
        case 'simple': {
            out = reporter_1.simpleReporter(params);
            break;
        }
        default: {
            out = reporter_1.standardReporter(params);
        }
    }
    if (!out.length) {
        return;
    }
    let msg = `${out.join('\n')}\n`;
    msg = params.color ? msg : strip_ansi_1.default(msg);
    // If it has errors, Write to `stderr` and failure and exit.
    if (params.results.length) {
        process.stderr.write(msg);
        process.exitCode = 1;
    }
    else if (!params.noStdOut) {
        process.stdout.write(msg);
    }
}
exports.output = output;
